# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gamenotifications.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steammessages_gamenotifications.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"9\n\x1b\x43GameNotifications_Variable\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"y\n CGameNotifications_LocalizedText\x12\r\n\x05token\x18\x01 \x01(\t\x12/\n\tvariables\x18\x02 \x03(\x0b\x32\x1c.CGameNotifications_Variable\x12\x15\n\rrendered_text\x18\x03 \x01(\t\"\xa5\x01\n\x1d\x43GameNotifications_UserStatus\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05state\x18\x02 \x01(\t\x12\x30\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12\x32\n\x07message\x18\x04 \x01(\x0b\x32!.CGameNotifications_LocalizedText\"\xbc\x01\n(CGameNotifications_CreateSession_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\x04\x12\x30\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12-\n\x05users\x18\x04 \x03(\x0b\x32\x1e.CGameNotifications_UserStatus\x12\x0f\n\x07steamid\x18\x05 \x01(\x06\">\n)CGameNotifications_CreateSession_Response\x12\x11\n\tsessionid\x18\x01 \x01(\x04\"]\n(CGameNotifications_DeleteSession_Request\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\"+\n)CGameNotifications_DeleteSession_Response\"\xbe\x01\n(CGameNotifications_UpdateSession_Request\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x30\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12-\n\x05users\x18\x04 \x03(\x0b\x32\x1e.CGameNotifications_UserStatus\x12\x0f\n\x07steamid\x18\x06 \x01(\x06\"+\n)CGameNotifications_UpdateSession_Response\"\x95\x01\n,CGameNotifications_EnumerateSessions_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12!\n\x19include_all_user_messages\x18\x03 \x01(\x08\x12!\n\x19include_auth_user_message\x18\x04 \x01(\x08\x12\x10\n\x08language\x18\x05 \x01(\t\"\xe2\x01\n\x1a\x43GameNotifications_Session\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\x04\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\x04\x12\x30\n\x05title\x18\x04 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12\x14\n\x0ctime_created\x18\x05 \x01(\r\x12\x14\n\x0ctime_updated\x18\x06 \x01(\r\x12\x33\n\x0buser_status\x18\x07 \x03(\x0b\x32\x1e.CGameNotifications_UserStatus\"^\n-CGameNotifications_EnumerateSessions_Response\x12-\n\x08sessions\x18\x01 \x03(\x0b\x32\x1b.CGameNotifications_Session\"\xeb\x01\n,CGameNotifications_GetSessionDetails_Request\x12P\n\x08sessions\x18\x01 \x03(\x0b\x32>.CGameNotifications_GetSessionDetails_Request.RequestedSession\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x10\n\x08language\x18\x03 \x01(\t\x1aH\n\x10RequestedSession\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12!\n\x19include_auth_user_message\x18\x03 \x01(\x08\"^\n-CGameNotifications_GetSessionDetails_Response\x12-\n\x08sessions\x18\x01 \x03(\x0b\x32\x1b.CGameNotifications_Session\"F\n\x18GameNotificationSettings\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1b\n\x13\x61llow_notifications\x18\x02 \x01(\x08\"v\n5CGameNotifications_UpdateNotificationSettings_Request\x12=\n\x1agame_notification_settings\x18\x01 \x03(\x0b\x32\x19.GameNotificationSettings\"8\n6CGameNotifications_UpdateNotificationSettings_Response\"Z\n8CGameNotifications_OnNotificationsRequested_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"\xa9\x01\n3CGameNotifications_OnUserStatusChanged_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tsessionid\x18\x02 \x01(\x04\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12.\n\x06status\x18\x04 \x01(\x0b\x32\x1e.CGameNotifications_UserStatus\x12\x0f\n\x07removed\x18\x05 \x01(\x08\x32\xcf\x05\n\x11GameNotifications\x12j\n\x11UserCreateSession\x12).CGameNotifications_CreateSession_Request\x1a*.CGameNotifications_CreateSession_Response\x12j\n\x11UserDeleteSession\x12).CGameNotifications_DeleteSession_Request\x1a*.CGameNotifications_DeleteSession_Response\x12j\n\x11UserUpdateSession\x12).CGameNotifications_UpdateSession_Request\x1a*.CGameNotifications_UpdateSession_Response\x12r\n\x11\x45numerateSessions\x12-.CGameNotifications_EnumerateSessions_Request\x1a..CGameNotifications_EnumerateSessions_Response\x12r\n\x11GetSessionDetails\x12-.CGameNotifications_GetSessionDetails_Request\x1a..CGameNotifications_GetSessionDetails_Response\x12\x8d\x01\n\x1aUpdateNotificationSettings\x12\x36.CGameNotifications_UpdateNotificationSettings_Request\x1a\x37.CGameNotifications_UpdateNotificationSettings_Response2\xdd\x01\n\x17GameNotificationsClient\x12\x62\n\x18OnNotificationsRequested\x12\x39.CGameNotifications_OnNotificationsRequested_Notification\x1a\x0b.NoResponse\x12X\n\x13OnUserStatusChanged\x12\x34.CGameNotifications_OnUserStatusChanged_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_gamenotifications_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _GAMENOTIFICATIONSCLIENT._options = None
  _GAMENOTIFICATIONSCLIENT._serialized_options = b'\300\265\030\002'
  _CGAMENOTIFICATIONS_VARIABLE._serialized_start=101
  _CGAMENOTIFICATIONS_VARIABLE._serialized_end=158
  _CGAMENOTIFICATIONS_LOCALIZEDTEXT._serialized_start=160
  _CGAMENOTIFICATIONS_LOCALIZEDTEXT._serialized_end=281
  _CGAMENOTIFICATIONS_USERSTATUS._serialized_start=284
  _CGAMENOTIFICATIONS_USERSTATUS._serialized_end=449
  _CGAMENOTIFICATIONS_CREATESESSION_REQUEST._serialized_start=452
  _CGAMENOTIFICATIONS_CREATESESSION_REQUEST._serialized_end=640
  _CGAMENOTIFICATIONS_CREATESESSION_RESPONSE._serialized_start=642
  _CGAMENOTIFICATIONS_CREATESESSION_RESPONSE._serialized_end=704
  _CGAMENOTIFICATIONS_DELETESESSION_REQUEST._serialized_start=706
  _CGAMENOTIFICATIONS_DELETESESSION_REQUEST._serialized_end=799
  _CGAMENOTIFICATIONS_DELETESESSION_RESPONSE._serialized_start=801
  _CGAMENOTIFICATIONS_DELETESESSION_RESPONSE._serialized_end=844
  _CGAMENOTIFICATIONS_UPDATESESSION_REQUEST._serialized_start=847
  _CGAMENOTIFICATIONS_UPDATESESSION_REQUEST._serialized_end=1037
  _CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE._serialized_start=1039
  _CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE._serialized_end=1082
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST._serialized_start=1085
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST._serialized_end=1234
  _CGAMENOTIFICATIONS_SESSION._serialized_start=1237
  _CGAMENOTIFICATIONS_SESSION._serialized_end=1463
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE._serialized_start=1465
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE._serialized_end=1559
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST._serialized_start=1562
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST._serialized_end=1797
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION._serialized_start=1725
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION._serialized_end=1797
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE._serialized_start=1799
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE._serialized_end=1893
  _GAMENOTIFICATIONSETTINGS._serialized_start=1895
  _GAMENOTIFICATIONSETTINGS._serialized_end=1965
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST._serialized_start=1967
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST._serialized_end=2085
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE._serialized_start=2087
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE._serialized_end=2143
  _CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION._serialized_start=2145
  _CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION._serialized_end=2235
  _CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION._serialized_start=2238
  _CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION._serialized_end=2407
  _GAMENOTIFICATIONS._serialized_start=2410
  _GAMENOTIFICATIONS._serialized_end=3129
  _GAMENOTIFICATIONSCLIENT._serialized_start=3132
  _GAMENOTIFICATIONSCLIENT._serialized_end=3353
_builder.BuildServices(DESCRIPTOR, 'steammessages_gamenotifications_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_depotbuilder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_depotbuilder.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xa4\x01\n&CContentBuilder_InitDepotBuild_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x17\n\x0fworkshop_itemid\x18\x03 \x01(\x04\x12\x14\n\x0c\x66or_local_cs\x18\x04 \x01(\x08\x12\x15\n\rtarget_branch\x18\x05 \x01(\t\x12\x14\n\x0cshader_depot\x18\x06 \x01(\x08\"\xa4\x03\n\'CContentBuilder_InitDepotBuild_Response\x12\x1b\n\x13\x62\x61seline_manifestid\x18\x01 \x01(\x04\x12\x12\n\nchunk_size\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x65s_key\x18\x03 \x01(\x0c\x12\x0f\n\x07rsa_key\x18\x04 \x01(\x0c\x12\x10\n\x08url_host\x18\x05 \x01(\t\x12 \n\x18offset_detection_enabled\x18\x06 \x01(\x08\x12(\n offset_detection_min_clean_chunk\x18\x07 \x01(\r\x12)\n!offset_detection_blast_radius_pre\x18\x08 \x01(\r\x12*\n\"offset_detection_blast_radius_post\x18\t \x01(\r\x12)\n!offset_detection_max_distance_pre\x18\n \x01(\r\x12*\n\"offset_detection_max_distance_post\x18\x0b \x01(\r\x12\x1a\n\x12\x63ompression_method\x18\x0c \x01(\r\"\xad\x01\n(CContentBuilder_StartDepotUpload_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x17\n\x0fworkshop_itemid\x18\x03 \x01(\x04\x12\x14\n\x0c\x66or_local_cs\x18\x04 \x01(\x08\x12\x1b\n\x13\x62\x61seline_manifestid\x18\x05 \x01(\x04\x12\x15\n\rmanifest_size\x18\x06 \x01(\r\"G\n)CContentBuilder_StartDepotUpload_Response\x12\x1a\n\x12\x64\x65pot_build_handle\x18\x01 \x01(\x04\"Z\n-CContentBuilder_GetMissingDepotChunks_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1a\n\x12\x64\x65pot_build_handle\x18\x02 \x01(\x04\"\xd2\x01\n.CContentBuilder_GetMissingDepotChunks_Response\x12N\n\x0emissing_chunks\x18\x01 \x03(\x0b\x32\x36.CContentBuilder_GetMissingDepotChunks_Response.Chunks\x12\x1c\n\x14total_missing_chunks\x18\x02 \x01(\r\x12\x1b\n\x13total_missing_bytes\x18\x03 \x01(\x04\x1a\x15\n\x06\x43hunks\x12\x0b\n\x03sha\x18\x01 \x01(\x0c\"V\n)CContentBuilder_FinishDepotUpload_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1a\n\x12\x64\x65pot_build_handle\x18\x02 \x01(\x04\"U\n*CContentBuilder_FinishDepotUpload_Response\x12\x12\n\nmanifestid\x18\x01 \x01(\x04\x12\x13\n\x0bprev_reused\x18\x02 \x01(\x08\"\xef\x01\n&CContentBuilder_CommitAppBuild_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12G\n\x0f\x64\x65pot_manifests\x18\x02 \x03(\x0b\x32..CContentBuilder_CommitAppBuild_Request.Depots\x12\x13\n\x0b\x62uild_notes\x18\x04 \x01(\t\x12\x13\n\x0blive_branch\x18\x05 \x01(\t\x12\x14\n\x0c\x66or_local_cs\x18\x06 \x01(\x08\x1a-\n\x06\x44\x65pots\x12\x0f\n\x07\x64\x65potid\x18\x01 \x01(\r\x12\x12\n\nmanifestid\x18\x02 \x01(\x04\":\n\'CContentBuilder_CommitAppBuild_Response\x12\x0f\n\x07\x62uildid\x18\x01 \x01(\r\"c\n)CContentBuilder_SignInstallScript_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x16\n\x0einstall_script\x18\x03 \x01(\t\"K\n*CContentBuilder_SignInstallScript_Response\x12\x1d\n\x15signed_install_script\x18\x01 \x01(\t2\x9b\x05\n\x0e\x43ontentBuilder\x12\x63\n\x0eInitDepotBuild\x12\'.CContentBuilder_InitDepotBuild_Request\x1a(.CContentBuilder_InitDepotBuild_Response\x12i\n\x10StartDepotUpload\x12).CContentBuilder_StartDepotUpload_Request\x1a*.CContentBuilder_StartDepotUpload_Response\x12x\n\x15GetMissingDepotChunks\x12..CContentBuilder_GetMissingDepotChunks_Request\x1a/.CContentBuilder_GetMissingDepotChunks_Response\x12l\n\x11\x46inishDepotUpload\x12*.CContentBuilder_FinishDepotUpload_Request\x1a+.CContentBuilder_FinishDepotUpload_Response\x12\x63\n\x0e\x43ommitAppBuild\x12\'.CContentBuilder_CommitAppBuild_Request\x1a(.CContentBuilder_CommitAppBuild_Response\x12l\n\x11SignInstallScript\x12*.CContentBuilder_SignInstallScript_Request\x1a+.CContentBuilder_SignInstallScript_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_depotbuilder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CCONTENTBUILDER_INITDEPOTBUILD_REQUEST._serialized_start=97
  _CCONTENTBUILDER_INITDEPOTBUILD_REQUEST._serialized_end=261
  _CCONTENTBUILDER_INITDEPOTBUILD_RESPONSE._serialized_start=264
  _CCONTENTBUILDER_INITDEPOTBUILD_RESPONSE._serialized_end=684
  _CCONTENTBUILDER_STARTDEPOTUPLOAD_REQUEST._serialized_start=687
  _CCONTENTBUILDER_STARTDEPOTUPLOAD_REQUEST._serialized_end=860
  _CCONTENTBUILDER_STARTDEPOTUPLOAD_RESPONSE._serialized_start=862
  _CCONTENTBUILDER_STARTDEPOTUPLOAD_RESPONSE._serialized_end=933
  _CCONTENTBUILDER_GETMISSINGDEPOTCHUNKS_REQUEST._serialized_start=935
  _CCONTENTBUILDER_GETMISSINGDEPOTCHUNKS_REQUEST._serialized_end=1025
  _CCONTENTBUILDER_GETMISSINGDEPOTCHUNKS_RESPONSE._serialized_start=1028
  _CCONTENTBUILDER_GETMISSINGDEPOTCHUNKS_RESPONSE._serialized_end=1238
  _CCONTENTBUILDER_GETMISSINGDEPOTCHUNKS_RESPONSE_CHUNKS._serialized_start=1217
  _CCONTENTBUILDER_GETMISSINGDEPOTCHUNKS_RESPONSE_CHUNKS._serialized_end=1238
  _CCONTENTBUILDER_FINISHDEPOTUPLOAD_REQUEST._serialized_start=1240
  _CCONTENTBUILDER_FINISHDEPOTUPLOAD_REQUEST._serialized_end=1326
  _CCONTENTBUILDER_FINISHDEPOTUPLOAD_RESPONSE._serialized_start=1328
  _CCONTENTBUILDER_FINISHDEPOTUPLOAD_RESPONSE._serialized_end=1413
  _CCONTENTBUILDER_COMMITAPPBUILD_REQUEST._serialized_start=1416
  _CCONTENTBUILDER_COMMITAPPBUILD_REQUEST._serialized_end=1655
  _CCONTENTBUILDER_COMMITAPPBUILD_REQUEST_DEPOTS._serialized_start=1610
  _CCONTENTBUILDER_COMMITAPPBUILD_REQUEST_DEPOTS._serialized_end=1655
  _CCONTENTBUILDER_COMMITAPPBUILD_RESPONSE._serialized_start=1657
  _CCONTENTBUILDER_COMMITAPPBUILD_RESPONSE._serialized_end=1715
  _CCONTENTBUILDER_SIGNINSTALLSCRIPT_REQUEST._serialized_start=1717
  _CCONTENTBUILDER_SIGNINSTALLSCRIPT_REQUEST._serialized_end=1816
  _CCONTENTBUILDER_SIGNINSTALLSCRIPT_RESPONSE._serialized_start=1818
  _CCONTENTBUILDER_SIGNINSTALLSCRIPT_RESPONSE._serialized_end=1893
  _CONTENTBUILDER._serialized_start=1896
  _CONTENTBUILDER._serialized_end=2563
_builder.BuildServices(DESCRIPTOR, 'steammessages_depotbuilder_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contenthubs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63ontenthubs.proto\"\xe1\x04\n\x10\x43StorePageFilter\x12\x35\n\x0bsale_filter\x18\x01 \x01(\x0b\x32 .CStorePageFilter.SalePageFilter\x12>\n\x12\x63ontent_hub_filter\x18\x02 \x01(\x0b\x32\".CStorePageFilter.ContentHubFilter\x12\x34\n\rstore_filters\x18\x03 \x03(\x0b\x32\x1d.CStorePageFilter.StoreFilter\x1a$\n\x0eSalePageFilter\x12\x12\n\nsale_tagid\x18\x01 \x01(\r\x1a\xc2\x02\n\x10\x43ontentHubFilter\x12\x10\n\x08hub_type\x18\x01 \x01(\t\x12\x14\n\x0chub_category\x18\x02 \x01(\t\x12\x11\n\thub_tagid\x18\x03 \x01(\r\x12]\n\x0f\x64iscount_filter\x18\x04 \x01(\x0e\x32\x1e.EContentHubDiscountFilterType:$k_EContentHubDiscountFilterType_None\x12;\n\x05optin\x18\x05 \x01(\x0b\x32,.CStorePageFilter.ContentHubFilter.OptInInfo\x1aW\n\tOptInInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0boptin_tagid\x18\x02 \x01(\r\x12\x13\n\x0bprune_tagid\x18\x03 \x01(\r\x12\x12\n\noptin_only\x18\x04 \x01(\x08\x1a\x35\n\x0bStoreFilter\x12\x13\n\x0b\x66ilter_json\x18\x01 \x01(\t\x12\x11\n\tcache_key\x18\x02 \x01(\t*\xb5\x01\n\x1d\x45\x43ontentHubDiscountFilterType\x12(\n$k_EContentHubDiscountFilterType_None\x10\x00\x12\x31\n-k_EContentHubDiscountFilterType_DiscountsOnly\x10\x01\x12\x37\n3k_EContentHubDiscountFilterType_PrioritizeDiscounts\x10\x02\x42\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'contenthubs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _ECONTENTHUBDISCOUNTFILTERTYPE._serialized_start=634
  _ECONTENTHUBDISCOUNTFILTERTYPE._serialized_end=815
  _CSTOREPAGEFILTER._serialized_start=22
  _CSTOREPAGEFILTER._serialized_end=631
  _CSTOREPAGEFILTER_SALEPAGEFILTER._serialized_start=215
  _CSTOREPAGEFILTER_SALEPAGEFILTER._serialized_end=251
  _CSTOREPAGEFILTER_CONTENTHUBFILTER._serialized_start=254
  _CSTOREPAGEFILTER_CONTENTHUBFILTER._serialized_end=576
  _CSTOREPAGEFILTER_CONTENTHUBFILTER_OPTININFO._serialized_start=489
  _CSTOREPAGEFILTER_CONTENTHUBFILTER_OPTININFO._serialized_end=576
  _CSTOREPAGEFILTER_STOREFILTER._serialized_start=578
  _CSTOREPAGEFILTER_STOREFILTER._serialized_end=631
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: test_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13test_messages.proto\"\xe9\x02\n\x13\x43omplexProtoMessage\x12\x10\n\x08number32\x18\x01 \x01(\r\x12\x10\n\x08number64\x18\x02 \x01(\x04\x12\x15\n\rlist_number32\x18\x03 \x03(\r\x12\x15\n\rlist_number64\x18\x04 \x03(\x04\x12\x33\n\x08messages\x18\x05 \x03(\x0b\x32!.ComplexProtoMessage.InnerMessage\x12\x31\n\x07\x62uffers\x18\x06 \x03(\x0b\x32 .ComplexProtoMessage.InnerBuffer\x1a-\n\x0cInnerMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07numbers\x18\x02 \x03(\r\x1ai\n\x0bInnerBuffer\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x35\n\x05\x66lags\x18\x02 \x03(\x0b\x32&.ComplexProtoMessage.InnerBuffer.Flags\x1a\x15\n\x05\x46lags\x12\x0c\n\x04\x66lag\x18\x01 \x01(\x08')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'test_messages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPLEXPROTOMESSAGE._serialized_start=24
  _COMPLEXPROTOMESSAGE._serialized_end=385
  _COMPLEXPROTOMESSAGE_INNERMESSAGE._serialized_start=233
  _COMPLEXPROTOMESSAGE_INNERMESSAGE._serialized_end=278
  _COMPLEXPROTOMESSAGE_INNERBUFFER._serialized_start=280
  _COMPLEXPROTOMESSAGE_INNERBUFFER._serialized_end=385
  _COMPLEXPROTOMESSAGE_INNERBUFFER_FLAGS._serialized_start=364
  _COMPLEXPROTOMESSAGE_INNERBUFFER_FLAGS._serialized_end=385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_site_license.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_site_license.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x8d\x01\n)CSiteManagerClient_IncomingClient_Request\x12\x17\n\x0fsite_instanceid\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_steamid\x18\x02 \x01(\x06\x12\x17\n\x0f\x63lient_local_ip\x18\x03 \x01(\x07\x12\x16\n\x0e\x63onnection_key\x18\x04 \x01(\x0c\",\n*CSiteManagerClient_IncomingClient_Response\"N\n,CSiteLicense_ClientSeatCheckout_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\"\xe3\x02\n/CSiteManagerClient_TrackedPayments_Notification\x12\x0f\n\x07site_id\x18\x01 \x01(\x06\x12J\n\x08payments\x18\x02 \x03(\x0b\x32\x38.CSiteManagerClient_TrackedPayments_Notification.Payment\x1a\xd2\x01\n\x07Payment\x12\x0f\n\x07transid\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x11\n\tecurrency\x18\x04 \x01(\r\x12\x14\n\x0ctime_created\x18\x05 \x01(\x05\x12\x17\n\x0fpurchase_status\x18\x06 \x01(\x05\x12\x14\n\x0cmachine_name\x18\x07 \x01(\t\x12\x14\n\x0cpersona_name\x18\x08 \x01(\t\x12\x13\n\x0bprofile_url\x18\t \x01(\t\x12\x12\n\navatar_url\x18\n \x01(\t\"r\n(CSiteLicense_InitiateAssociation_Request\x12\x14\n\x0csite_steamid\x18\x01 \x01(\x06\x12\x17\n\x0fsite_instanceid\x18\x02 \x01(\x06\x12\x17\n\x0f\x63lient_local_ip\x18\x03 \x01(\x07\"C\n)CSiteLicense_InitiateAssociation_Response\x12\x16\n\x0e\x63onnection_key\x18\x01 \x01(\x0c\":\n$CSiteLicense_LCSAuthenticate_Request\x12\x12\n\ninstanceid\x18\x01 \x01(\x06\"z\n%CSiteLicense_LCSAuthenticate_Response\x12\x0f\n\x07site_id\x18\x01 \x01(\x04\x12\x11\n\tsite_name\x18\x02 \x01(\t\x12\x13\n\x0bnew_session\x18\x03 \x01(\x08\x12\x18\n\x10no_site_licenses\x18\x04 \x01(\x08\"t\n%CSiteLicense_LCSAssociateUser_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08local_ip\x18\x02 \x01(\x07\x12\x12\n\ninstanceid\x18\x03 \x01(\x06\x12\x14\n\x0cmachine_name\x18\x04 \x01(\t\"(\n&CSiteLicense_LCSAssociateUser_Response\"]\n\'CSiteLicense_ClientSeatCheckout_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x12\n\ninstanceid\x18\x02 \x01(\x06\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"*\n(CSiteLicense_ClientSeatCheckout_Response\"b\n,CSiteLicense_ClientGetAvailableSeats_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x12\n\ninstanceid\x18\x02 \x01(\x06\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"H\n-CSiteLicense_ClientGetAvailableSeats_Response\x12\x17\n\x0f\x61vailable_seats\x18\x01 \x01(\r2\xc0\x02\n\x11SiteManagerClient\x12i\n\x0eIncomingClient\x12*.CSiteManagerClient_IncomingClient_Request\x1a+.CSiteManagerClient_IncomingClient_Response\x12\\\n\x1e\x43lientSeatCheckoutNotification\x12-.CSiteLicense_ClientSeatCheckout_Notification\x1a\x0b.NoResponse\x12\\\n\x1bTrackedPaymentsNotification\x12\x30.CSiteManagerClient_TrackedPayments_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x32\xa7\x04\n\x0bSiteLicense\x12l\n\x13InitiateAssociation\x12).CSiteLicense_InitiateAssociation_Request\x1a*.CSiteLicense_InitiateAssociation_Response\x12`\n\x0fLCSAuthenticate\x12%.CSiteLicense_LCSAuthenticate_Request\x1a&.CSiteLicense_LCSAuthenticate_Response\x12\x63\n\x10LCSAssociateUser\x12&.CSiteLicense_LCSAssociateUser_Request\x1a\'.CSiteLicense_LCSAssociateUser_Response\x12i\n\x12\x43lientSeatCheckout\x12(.CSiteLicense_ClientSeatCheckout_Request\x1a).CSiteLicense_ClientSeatCheckout_Response\x12x\n\x17\x43lientGetAvailableSeats\x12-.CSiteLicense_ClientGetAvailableSeats_Request\x1a..CSiteLicense_ClientGetAvailableSeats_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_site_license_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _SITEMANAGERCLIENT._options = None
  _SITEMANAGERCLIENT._serialized_options = b'\300\265\030\002'
  _CSITEMANAGERCLIENT_INCOMINGCLIENT_REQUEST._serialized_start=97
  _CSITEMANAGERCLIENT_INCOMINGCLIENT_REQUEST._serialized_end=238
  _CSITEMANAGERCLIENT_INCOMINGCLIENT_RESPONSE._serialized_start=240
  _CSITEMANAGERCLIENT_INCOMINGCLIENT_RESPONSE._serialized_end=284
  _CSITELICENSE_CLIENTSEATCHECKOUT_NOTIFICATION._serialized_start=286
  _CSITELICENSE_CLIENTSEATCHECKOUT_NOTIFICATION._serialized_end=364
  _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION._serialized_start=367
  _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION._serialized_end=722
  _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION_PAYMENT._serialized_start=512
  _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION_PAYMENT._serialized_end=722
  _CSITELICENSE_INITIATEASSOCIATION_REQUEST._serialized_start=724
  _CSITELICENSE_INITIATEASSOCIATION_REQUEST._serialized_end=838
  _CSITELICENSE_INITIATEASSOCIATION_RESPONSE._serialized_start=840
  _CSITELICENSE_INITIATEASSOCIATION_RESPONSE._serialized_end=907
  _CSITELICENSE_LCSAUTHENTICATE_REQUEST._serialized_start=909
  _CSITELICENSE_LCSAUTHENTICATE_REQUEST._serialized_end=967
  _CSITELICENSE_LCSAUTHENTICATE_RESPONSE._serialized_start=969
  _CSITELICENSE_LCSAUTHENTICATE_RESPONSE._serialized_end=1091
  _CSITELICENSE_LCSASSOCIATEUSER_REQUEST._serialized_start=1093
  _CSITELICENSE_LCSASSOCIATEUSER_REQUEST._serialized_end=1209
  _CSITELICENSE_LCSASSOCIATEUSER_RESPONSE._serialized_start=1211
  _CSITELICENSE_LCSASSOCIATEUSER_RESPONSE._serialized_end=1251
  _CSITELICENSE_CLIENTSEATCHECKOUT_REQUEST._serialized_start=1253
  _CSITELICENSE_CLIENTSEATCHECKOUT_REQUEST._serialized_end=1346
  _CSITELICENSE_CLIENTSEATCHECKOUT_RESPONSE._serialized_start=1348
  _CSITELICENSE_CLIENTSEATCHECKOUT_RESPONSE._serialized_end=1390
  _CSITELICENSE_CLIENTGETAVAILABLESEATS_REQUEST._serialized_start=1392
  _CSITELICENSE_CLIENTGETAVAILABLESEATS_REQUEST._serialized_end=1490
  _CSITELICENSE_CLIENTGETAVAILABLESEATS_RESPONSE._serialized_start=1492
  _CSITELICENSE_CLIENTGETAVAILABLESEATS_RESPONSE._serialized_end=1564
  _SITEMANAGERCLIENT._serialized_start=1567
  _SITEMANAGERCLIENT._serialized_end=1887
  _SITELICENSE._serialized_start=1890
  _SITELICENSE._serialized_end=2441
_builder.BuildServices(DESCRIPTOR, 'steammessages_site_license_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_credentials.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_credentials.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xa2\x01\n)CCredentials_GetSteamGuardDetails_Request\x12\x11\n\twebcookie\x18\x02 \x01(\t\x12 \n\x18timestamp_minimum_wanted\x18\x03 \x01(\x07\x12\x1c\n\x14\x64\x65precated_ipaddress\x18\x04 \x01(\x05\x12\"\n\nip_address\x18\x05 \x01(\x0b\x32\x0e.CMsgIPAddress\"\xff\x05\n*CCredentials_GetSteamGuardDetails_Response\x12\x1d\n\x15is_steamguard_enabled\x18\x01 \x01(\x08\x12$\n\x1ctimestamp_steamguard_enabled\x18\x02 \x01(\x07\x12*\n\"deprecated_machine_name_userchosen\x18\x04 \x01(\t\x12\x37\n/deprecated_timestamp_machine_steamguard_enabled\x18\x05 \x01(\x07\x12\x43\n;deprecated_authentication_exists_from_geoloc_before_mintime\x18\x06 \x01(\x08\x12\x1d\n\x15\x64\x65precated_machine_id\x18\x07 \x01(\x04\x12M\n\x0csession_data\x18\x08 \x03(\x0b\x32\x37.CCredentials_GetSteamGuardDetails_Response.SessionData\x12\x1c\n\x14is_twofactor_enabled\x18\t \x01(\x08\x12#\n\x1btimestamp_twofactor_enabled\x18\n \x01(\x07\x12\x19\n\x11is_phone_verified\x18\x0b \x01(\x08\x1a\x95\x02\n\x0bSessionData\x12\x12\n\nmachine_id\x18\x01 \x01(\x04\x12\x1f\n\x17machine_name_userchosen\x18\x02 \x01(\t\x12,\n$timestamp_machine_steamguard_enabled\x18\x03 \x01(\x07\x12\x38\n0authentication_exists_from_geoloc_before_mintime\x18\x04 \x01(\x08\x12\x39\n1authentication_exists_from_same_ip_before_mintime\x18\x06 \x01(\x08\x12\x13\n\x0bpublic_ipv4\x18\x07 \x01(\r\x12\x19\n\x11public_ip_address\x18\x08 \x01(\t\";\n)CCredentials_ValidateEmailAddress_Request\x12\x0e\n\x06stoken\x18\x01 \x01(\t\"C\n*CCredentials_ValidateEmailAddress_Response\x12\x15\n\rwas_validated\x18\x01 \x01(\x08\"_\n-CCredentials_SteamGuardPhishingReport_Request\x12\x14\n\x0cparam_string\x18\x01 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x02 \x01(\t\"\xb3\x02\n.CCredentials_SteamGuardPhishingReport_Response\x12\x1e\n\x16ipaddress_loginattempt\x18\x01 \x01(\t\x12 \n\x18\x63ountryname_loginattempt\x18\x02 \x01(\t\x12\x1e\n\x16statename_loginattempt\x18\x03 \x01(\t\x12\x1d\n\x15\x63ityname_loginattempt\x18\x04 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x05 \x01(\t\x12\x1a\n\x12\x63ountryname_actual\x18\x06 \x01(\t\x12\x18\n\x10statename_actual\x18\x07 \x01(\t\x12\x17\n\x0f\x63ityname_actual\x18\x08 \x01(\t\x12\x17\n\x0fsteamguard_code\x18\t \x01(\t\"J\n-CCredentials_LastCredentialChangeTime_Request\x12\x19\n\x11user_changes_only\x18\x01 \x01(\x08\"\xa4\x01\n.CCredentials_LastCredentialChangeTime_Response\x12&\n\x1etimestamp_last_password_change\x18\x01 \x01(\x07\x12#\n\x1btimestamp_last_email_change\x18\x02 \x01(\x07\x12%\n\x1dtimestamp_last_password_reset\x18\x03 \x01(\x07\"+\n)CCredentials_GetAccountAuthSecret_Request\"O\n*CCredentials_GetAccountAuthSecret_Response\x12\x11\n\tsecret_id\x18\x01 \x01(\x05\x12\x0e\n\x06secret\x18\x02 \x01(\x0c\x32\xe1\x04\n\x0b\x43redentials\x12o\n\x14GetSteamGuardDetails\x12*.CCredentials_GetSteamGuardDetails_Request\x1a+.CCredentials_GetSteamGuardDetails_Response\x12o\n\x14ValidateEmailAddress\x12*.CCredentials_ValidateEmailAddress_Request\x1a+.CCredentials_ValidateEmailAddress_Response\x12{\n\x18SteamGuardPhishingReport\x12..CCredentials_SteamGuardPhishingReport_Request\x1a/.CCredentials_SteamGuardPhishingReport_Response\x12\x81\x01\n\x1eGetCredentialChangeTimeDetails\x12..CCredentials_LastCredentialChangeTime_Request\x1a/.CCredentials_LastCredentialChangeTime_Response\x12o\n\x14GetAccountAuthSecret\x12*.CCredentials_GetAccountAuthSecret_Request\x1a+.CCredentials_GetAccountAuthSecret_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_credentials_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST._serialized_start=96
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST._serialized_end=258
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE._serialized_start=261
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE._serialized_end=1028
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA._serialized_start=751
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA._serialized_end=1028
  _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST._serialized_start=1030
  _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST._serialized_end=1089
  _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE._serialized_start=1091
  _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE._serialized_end=1158
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST._serialized_start=1160
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST._serialized_end=1255
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE._serialized_start=1258
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE._serialized_end=1565
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST._serialized_start=1567
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST._serialized_end=1641
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE._serialized_start=1644
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE._serialized_end=1808
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST._serialized_start=1810
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST._serialized_end=1853
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE._serialized_start=1855
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE._serialized_end=1934
  _CREDENTIALS._serialized_start=1937
  _CREDENTIALS._serialized_end=2546
_builder.BuildServices(DESCRIPTOR, 'steammessages_credentials_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_transportvalidation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'webuimessages_transportvalidation.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"E\n+CTransportValidation_AppendToString_Request\x12\x16\n\x0e\x61ppend_strings\x18\x01 \x03(\t\"E\n,CTransportValidation_AppendToString_Response\x12\x15\n\rcombined_text\x18\x01 \x01(\t\"<\n,CTransportValidation_NotifyText_Notification\x12\x0c\n\x04text\x18\x01 \x01(\t\"@\n.CTransportValidation_NotifyNumber_Notification\x12\x0e\n\x06number\x18\x01 \x01(\x05\"2\n0CTransportValidation_GetLastNotifyNumber_Request\"O\n1CTransportValidation_GetLastNotifyNumber_Response\x12\x1a\n\x12last_notify_number\x18\x01 \x01(\x05\"D\n3CTransportValidation_TriggerSyntheticEvents_Request\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"6\n4CTransportValidation_TriggerSyntheticEvents_Response\"J\n6CTransportValidation_NotifySyntheticEvent_Notification\x12\x10\n\x08sequence\x18\x01 \x01(\x05\"1\n/CTransportValidation_TriggerDataRequest_Request\"@\n0CTransportValidation_TriggerDataRequest_Response\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x05\"*\n(CTransportValidation_DataRequest_Request\"9\n)CTransportValidation_DataRequest_Response\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x05\":\n\'CTransportValidation_AddNumbers_Request\x12\x0f\n\x07numbers\x18\x01 \x03(\x05\"?\n(CTransportValidation_AddNumbers_Response\x12\x13\n\x0b\x61\x63\x63umulated\x18\x01 \x01(\x05\"G\n.CTransportValidation_CountOrderedBytes_Request\x12\x15\n\rordered_bytes\x18\x01 \x01(\x0c\"E\n/CTransportValidation_CountOrderedBytes_Response\x12\x12\n\nbyte_count\x18\x01 \x01(\x05\"P\n*CTransportValidation_ThreadedCount_Request\x12\x11\n\tstart_num\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nd_num\x18\x02 \x01(\x05\"-\n+CTransportValidation_ThreadedCount_Response\"<\n-CTransportValidation_NotifyCount_Notification\x12\x0b\n\x03num\x18\x01 \x01(\x05\"1\n/CTransportValidation_RequestInvalidBool_Request\"a\n0CTransportValidation_RequestInvalidBool_Response\x12\x0e\n\x06\x62\x65\x66ore\x18\x01 \x01(\x05\x12\x0e\n\x06output\x18\x02 \x01(\x08\x12\r\n\x05\x61\x66ter\x18\x03 \x01(\x05\"B\n-CTransportValidation_GetLargeResponse_Request\x12\x11\n\tdata_size\x18\x01 \x01(\r\">\n.CTransportValidation_GetLargeResponse_Response\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"J\n5CTransportValidation_RequestLargeNotification_Request\x12\x11\n\tdata_size\x18\x01 \x01(\r\"8\n6CTransportValidation_RequestLargeNotification_Response\"=\n-CTransportValidation_NotifyLarge_Notification\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"@\n-CTransportValidationClient_AddNumbers_Request\x12\x0f\n\x07numbers\x18\x01 \x03(\x05\"E\n.CTransportValidationClient_AddNumbers_Response\x12\x13\n\x0b\x61\x63\x63umulated\x18\x01 \x01(\x05\x32\xe5\x0c\n\x13TransportValidation\x12m\n\x0e\x41ppendToString\x12,.CTransportValidation_AppendToString_Request\x1a-.CTransportValidation_AppendToString_Response\x12\x61\n\nAddNumbers\x12(.CTransportValidation_AddNumbers_Request\x1a).CTransportValidation_AddNumbers_Response\x12g\n\x10\x41\x64\x64NumbersStatic\x12(.CTransportValidation_AddNumbers_Request\x1a).CTransportValidation_AddNumbers_Response\x12M\n\nNotifyText\x12-.CTransportValidation_NotifyText_Notification\x1a\x10.WebUINoResponse\x12Q\n\x0cNotifyNumber\x12/.CTransportValidation_NotifyNumber_Notification\x1a\x10.WebUINoResponse\x12|\n\x13GetLastNotifyNumber\x12\x31.CTransportValidation_GetLastNotifyNumber_Request\x1a\x32.CTransportValidation_GetLastNotifyNumber_Response\x12\x61\n\x14NotifySyntheticEvent\x12\x37.CTransportValidation_NotifySyntheticEvent_Notification\x1a\x10.WebUINoResponse\x12\x85\x01\n\x16TriggerSyntheticEvents\x12\x34.CTransportValidation_TriggerSyntheticEvents_Request\x1a\x35.CTransportValidation_TriggerSyntheticEvents_Response\x12v\n\x11\x43ountOrderedBytes\x12/.CTransportValidation_CountOrderedBytes_Request\x1a\x30.CTransportValidation_CountOrderedBytes_Response\x12j\n\rThreadedCount\x12+.CTransportValidation_ThreadedCount_Request\x1a,.CTransportValidation_ThreadedCount_Response\x12O\n\x0bNotifyCount\x12..CTransportValidation_NotifyCount_Notification\x1a\x10.WebUINoResponse\x12y\n\x12RequestInvalidBool\x12\x30.CTransportValidation_RequestInvalidBool_Request\x1a\x31.CTransportValidation_RequestInvalidBool_Response\x12s\n\x10GetLargeResponse\x12..CTransportValidation_GetLargeResponse_Request\x1a/.CTransportValidation_GetLargeResponse_Response\x12\x8b\x01\n\x18RequestLargeNotification\x12\x36.CTransportValidation_RequestLargeNotification_Request\x1a\x37.CTransportValidation_RequestLargeNotification_Response\x12O\n\x0bNotifyLarge\x12..CTransportValidation_NotifyLarge_Notification\x1a\x10.WebUINoResponse\x1a\x04\x80\x97\"\x01\x32\x90\x01\n\x19TransportValidationClient\x12m\n\nAddNumbers\x12..CTransportValidationClient_AddNumbers_Request\x1a/.CTransportValidationClient_AddNumbers_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_transportvalidation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _TRANSPORTVALIDATION._options = None
  _TRANSPORTVALIDATION._serialized_options = b'\200\227\"\001'
  _TRANSPORTVALIDATIONCLIENT._options = None
  _TRANSPORTVALIDATIONCLIENT._serialized_options = b'\200\227\"\002'
  _CTRANSPORTVALIDATION_APPENDTOSTRING_REQUEST._serialized_start=95
  _CTRANSPORTVALIDATION_APPENDTOSTRING_REQUEST._serialized_end=164
  _CTRANSPORTVALIDATION_APPENDTOSTRING_RESPONSE._serialized_start=166
  _CTRANSPORTVALIDATION_APPENDTOSTRING_RESPONSE._serialized_end=235
  _CTRANSPORTVALIDATION_NOTIFYTEXT_NOTIFICATION._serialized_start=237
  _CTRANSPORTVALIDATION_NOTIFYTEXT_NOTIFICATION._serialized_end=297
  _CTRANSPORTVALIDATION_NOTIFYNUMBER_NOTIFICATION._serialized_start=299
  _CTRANSPORTVALIDATION_NOTIFYNUMBER_NOTIFICATION._serialized_end=363
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_REQUEST._serialized_start=365
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_REQUEST._serialized_end=415
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_RESPONSE._serialized_start=417
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_RESPONSE._serialized_end=496
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_REQUEST._serialized_start=498
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_REQUEST._serialized_end=566
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_RESPONSE._serialized_start=568
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_RESPONSE._serialized_end=622
  _CTRANSPORTVALIDATION_NOTIFYSYNTHETICEVENT_NOTIFICATION._serialized_start=624
  _CTRANSPORTVALIDATION_NOTIFYSYNTHETICEVENT_NOTIFICATION._serialized_end=698
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_REQUEST._serialized_start=700
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_REQUEST._serialized_end=749
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_RESPONSE._serialized_start=751
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_RESPONSE._serialized_end=815
  _CTRANSPORTVALIDATION_DATAREQUEST_REQUEST._serialized_start=817
  _CTRANSPORTVALIDATION_DATAREQUEST_REQUEST._serialized_end=859
  _CTRANSPORTVALIDATION_DATAREQUEST_RESPONSE._serialized_start=861
  _CTRANSPORTVALIDATION_DATAREQUEST_RESPONSE._serialized_end=918
  _CTRANSPORTVALIDATION_ADDNUMBERS_REQUEST._serialized_start=920
  _CTRANSPORTVALIDATION_ADDNUMBERS_REQUEST._serialized_end=978
  _CTRANSPORTVALIDATION_ADDNUMBERS_RESPONSE._serialized_start=980
  _CTRANSPORTVALIDATION_ADDNUMBERS_RESPONSE._serialized_end=1043
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_REQUEST._serialized_start=1045
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_REQUEST._serialized_end=1116
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_RESPONSE._serialized_start=1118
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_RESPONSE._serialized_end=1187
  _CTRANSPORTVALIDATION_THREADEDCOUNT_REQUEST._serialized_start=1189
  _CTRANSPORTVALIDATION_THREADEDCOUNT_REQUEST._serialized_end=1269
  _CTRANSPORTVALIDATION_THREADEDCOUNT_RESPONSE._serialized_start=1271
  _CTRANSPORTVALIDATION_THREADEDCOUNT_RESPONSE._serialized_end=1316
  _CTRANSPORTVALIDATION_NOTIFYCOUNT_NOTIFICATION._serialized_start=1318
  _CTRANSPORTVALIDATION_NOTIFYCOUNT_NOTIFICATION._serialized_end=1378
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_REQUEST._serialized_start=1380
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_REQUEST._serialized_end=1429
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_RESPONSE._serialized_start=1431
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_RESPONSE._serialized_end=1528
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_REQUEST._serialized_start=1530
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_REQUEST._serialized_end=1596
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_RESPONSE._serialized_start=1598
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_RESPONSE._serialized_end=1660
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_REQUEST._serialized_start=1662
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_REQUEST._serialized_end=1736
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_RESPONSE._serialized_start=1738
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_RESPONSE._serialized_end=1794
  _CTRANSPORTVALIDATION_NOTIFYLARGE_NOTIFICATION._serialized_start=1796
  _CTRANSPORTVALIDATION_NOTIFYLARGE_NOTIFICATION._serialized_end=1857
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_REQUEST._serialized_start=1859
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_REQUEST._serialized_end=1923
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_RESPONSE._serialized_start=1925
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_RESPONSE._serialized_end=1994
  _TRANSPORTVALIDATION._serialized_start=1997
  _TRANSPORTVALIDATION._serialized_end=3634
  _TRANSPORTVALIDATIONCLIENT._serialized_start=3637
  _TRANSPORTVALIDATIONCLIENT._serialized_end=3781
_builder.BuildServices(DESCRIPTOR, 'webuimessages_transportvalidation_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_notifications.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_notifications.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x88\x02\n\x15SteamNotificationData\x12\x17\n\x0fnotification_id\x18\x01 \x01(\x04\x12\x1c\n\x14notification_targets\x18\x02 \x01(\r\x12T\n\x11notification_type\x18\x03 \x01(\x0e\x32\x17.ESteamNotificationType: k_ESteamNotificationType_Invalid\x12\x11\n\tbody_data\x18\x04 \x01(\t\x12\x0c\n\x04read\x18\x07 \x01(\x08\x12\x11\n\ttimestamp\x18\x08 \x01(\r\x12\x0e\n\x06hidden\x18\t \x01(\x08\x12\x0e\n\x06\x65xpiry\x18\n \x01(\r\x12\x0e\n\x06viewed\x18\x0b \x01(\r\"\xc5\x01\n5CSteamNotification_NotificationsReceived_Notification\x12-\n\rnotifications\x18\x01 \x03(\x0b\x32\x16.SteamNotificationData\x12\x1a\n\x12pending_gift_count\x18\x02 \x01(\r\x12\x1c\n\x14pending_friend_count\x18\x03 \x01(\r\x12#\n\x1bpending_family_invite_count\x18\x04 \x01(\r\"\x91\x01\n\x1bSteamNotificationPreference\x12T\n\x11notification_type\x18\x01 \x01(\x0e\x32\x17.ESteamNotificationType: k_ESteamNotificationType_Invalid\x12\x1c\n\x14notification_targets\x18\x02 \x01(\r\"g\n2CSteamNotification_PreferencesUpdated_Notification\x12\x31\n\x0bpreferences\x18\x01 \x03(\x0b\x32\x1c.SteamNotificationPreference*\xcc\n\n\x16\x45SteamNotificationType\x12$\n k_ESteamNotificationType_Invalid\x10\x00\x12!\n\x1dk_ESteamNotificationType_Test\x10\x01\x12!\n\x1dk_ESteamNotificationType_Gift\x10\x02\x12$\n k_ESteamNotificationType_Comment\x10\x03\x12!\n\x1dk_ESteamNotificationType_Item\x10\x04\x12)\n%k_ESteamNotificationType_FriendInvite\x10\x05\x12&\n\"k_ESteamNotificationType_MajorSale\x10\x06\x12-\n)k_ESteamNotificationType_PreloadAvailable\x10\x07\x12%\n!k_ESteamNotificationType_Wishlist\x10\x08\x12\'\n#k_ESteamNotificationType_TradeOffer\x10\t\x12$\n k_ESteamNotificationType_General\x10\n\x12(\n$k_ESteamNotificationType_HelpRequest\x10\x0b\x12&\n\"k_ESteamNotificationType_AsyncGame\x10\x0c\x12$\n k_ESteamNotificationType_ChatMsg\x10\r\x12)\n%k_ESteamNotificationType_ModeratorMsg\x10\x0e\x12\x39\n5k_ESteamNotificationType_ParentalFeatureAccessRequest\x10\x0f\x12)\n%k_ESteamNotificationType_FamilyInvite\x10\x10\x12\x32\n.k_ESteamNotificationType_FamilyPurchaseRequest\x10\x11\x12\x34\n0k_ESteamNotificationType_ParentalPlaytimeRequest\x10\x12\x12:\n6k_ESteamNotificationType_FamilyPurchaseRequestResponse\x10\x13\x12:\n6k_ESteamNotificationType_ParentalFeatureAccessResponse\x10\x14\x12\x35\n1k_ESteamNotificationType_ParentalPlaytimeResponse\x10\x15\x12/\n+k_ESteamNotificationType_RequestedGameAdded\x10\x16\x12(\n$k_ESteamNotificationType_SendToPhone\x10\x17\x12+\n\'k_ESteamNotificationType_ClipDownloaded\x10\x18\x12&\n\"k_ESteamNotificationType_2FAPrompt\x10\x19\x12/\n+k_ESteamNotificationType_MobileConfirmation\x10\x1a\x12)\n%k_ESteamNotificationType_PartnerEvent\x10\x1b\x12+\n\'k_ESteamNotificationType_PlaytestInvite\x10\x1c\x12*\n&k_ESteamNotificationType_TradeReversal\x10\x1d\x32\xd5\x01\n\x17SteamNotificationClient\x12\\\n\x15NotificationsReceived\x12\x36.CSteamNotification_NotificationsReceived_Notification\x1a\x0b.NoResponse\x12V\n\x12PreferencesUpdated\x12\x33.CSteamNotification_PreferencesUpdated_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_notifications_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _STEAMNOTIFICATIONCLIENT._options = None
  _STEAMNOTIFICATIONCLIENT._serialized_options = b'\300\265\030\002'
  _ESTEAMNOTIFICATIONTYPE._serialized_start=818
  _ESTEAMNOTIFICATIONTYPE._serialized_end=2174
  _STEAMNOTIFICATIONDATA._serialized_start=98
  _STEAMNOTIFICATIONDATA._serialized_end=362
  _CSTEAMNOTIFICATION_NOTIFICATIONSRECEIVED_NOTIFICATION._serialized_start=365
  _CSTEAMNOTIFICATION_NOTIFICATIONSRECEIVED_NOTIFICATION._serialized_end=562
  _STEAMNOTIFICATIONPREFERENCE._serialized_start=565
  _STEAMNOTIFICATIONPREFERENCE._serialized_end=710
  _CSTEAMNOTIFICATION_PREFERENCESUPDATED_NOTIFICATION._serialized_start=712
  _CSTEAMNOTIFICATION_PREFERENCESUPDATED_NOTIFICATION._serialized_end=815
  _STEAMNOTIFICATIONCLIENT._serialized_start=2177
  _STEAMNOTIFICATIONCLIENT._serialized_end=2390
_builder.BuildServices(DESCRIPTOR, 'steammessages_notifications_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_sharedjscontext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#webuimessages_sharedjscontext.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"3\n1CSharedJSContext_GetDesiredSteamUIWindows_Request\"\xd2\x01\n\x18\x43MsgSteamUIBrowserWindow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x12\n\nbrowser_id\x18\x03 \x01(\x05\x12\x13\n\x0bwindow_type\x18\x04 \x01(\x05\x12\t\n\x01x\x18\x05 \x01(\x05\x12\t\n\x01y\x18\x06 \x01(\x05\x12\r\n\x05\x61ppid\x18\x07 \x01(\x04\x12\x1c\n\x14parent_window_handle\x18\x08 \x01(\x04\x12\x10\n\x08\x61pp_name\x18\t \x01(\t\x12\x1f\n\x17gamepadui_via_gamescope\x18\n \x01(\x08\"`\n2CSharedJSContext_GetDesiredSteamUIWindows_Response\x12*\n\x07windows\x18\x01 \x03(\x0b\x32\x19.CMsgSteamUIBrowserWindow2\x9d\x01\n\x0fSharedJSContext\x12\x83\x01\n\x18GetDesiredSteamUIWindows\x12\x32.CSharedJSContext_GetDesiredSteamUIWindows_Request\x1a\x33.CSharedJSContext_GetDesiredSteamUIWindows_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_sharedjscontext_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _SHAREDJSCONTEXT._options = None
  _SHAREDJSCONTEXT._serialized_options = b'\200\227\"\001'
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_REQUEST._serialized_start=104
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_REQUEST._serialized_end=155
  _CMSGSTEAMUIBROWSERWINDOW._serialized_start=158
  _CMSGSTEAMUIBROWSERWINDOW._serialized_end=368
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_RESPONSE._serialized_start=370
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_RESPONSE._serialized_end=466
  _SHAREDJSCONTEXT._serialized_start=469
  _SHAREDJSCONTEXT._serialized_end=626
_builder.BuildServices(DESCRIPTOR, 'webuimessages_sharedjscontext_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_qms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17steammessages_qms.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"2\n\x0fGameSearchParam\x12\x10\n\x08key_name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\"\xe9\x01\n(CQueuedMatchmaking_SearchForGame_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x12\n\nplayer_min\x18\x04 \x01(\r\x12\x12\n\nplayer_max\x18\x05 \x01(\r\x12\x14\n\x0csteamidlobby\x18\x06 \x01(\x06\x12\x10\n\x08searchid\x18\x07 \x01(\x04\"\x87\x03\n)CQueuedMatchmaking_SearchForGame_Response\x12I\n\x10gamesearchresult\x18\x01 \x01(\x0e\x32\x12.EGameSearchResult:\x1bk_EGameSearchResult_Invalid\x12\x10\n\x08searchid\x18\x02 \x01(\x04\x12\x1d\n\x15seconds_time_estimate\x18\x03 \x01(\r\x12\x16\n\x0epoll_frequency\x18\x04 \x01(\r\x12\x17\n\x0f\x63ount_searching\x18\x05 \x01(\r\x12\x18\n\x10players_in_match\x18\x06 \x01(\r\x12\x18\n\x10players_accepted\x18\x07 \x01(\r\x12\x16\n\x0e\x63onnect_string\x18\t \x01(\t\x12\x13\n\x0bsteamidhost\x18\n \x01(\x06\x12\x18\n\x10rtime_match_made\x18\x0b \x01(\r\x12\x11\n\trtime_now\x18\x0c \x01(\r\x12\x1f\n\x17steamid_canceled_search\x18\r \x01(\x06\"\x97\x02\n3CQueuedMatchmakingGameHost_SearchForPlayers_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x12\n\nplayer_min\x18\x04 \x01(\r\x12\x12\n\nplayer_max\x18\x05 \x01(\r\x12\x1c\n\x14player_max_team_size\x18\x06 \x01(\r\x12\x19\n\x11\x63onnection_string\x18\x07 \x01(\t\x12\x10\n\x08searchid\x18\x08 \x01(\x04\"\x93\x01\n\x0bPlayerFound\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x13\n\x0bteam_number\x18\x04 \x01(\r\"\x88\x02\n4CQueuedMatchmakingGameHost_SearchForPlayers_Response\x12I\n\x10gamesearchresult\x18\x01 \x01(\x0e\x32\x12.EGameSearchResult:\x1bk_EGameSearchResult_Invalid\x12\x10\n\x08searchid\x18\x02 \x01(\x04\x12\x16\n\x0epoll_frequency\x18\x03 \x01(\r\x12\x0f\n\x07matchid\x18\x04 \x01(\x04\x12\x1d\n\x07players\x18\x05 \x03(\x0b\x32\x0c.PlayerFound\x12\x18\n\x10rtime_match_made\x18\x06 \x01(\r\x12\x11\n\trtime_now\x18\x07 \x01(\r\".\n\x0cPlayerResult\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05value\x18\x02 \x01(\r\"~\n5CQueuedMatchmakingGameHost_SubmitPlayerResult_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\x12%\n\x0eplayer_results\x18\x03 \x03(\x0b\x32\r.PlayerResult\"8\n6CQueuedMatchmakingGameHost_SubmitPlayerResult_Response\"L\n*CQueuedMatchmakingGameHost_EndGame_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\"-\n+CQueuedMatchmakingGameHost_EndGame_Response*\x92\x01\n\x11\x45GameSearchAction\x12\x1c\n\x18k_EGameSearchAction_None\x10\x00\x12\x1e\n\x1ak_EGameSearchAction_Accept\x10\x01\x12\x1f\n\x1bk_EGameSearchAction_Decline\x10\x02\x12\x1e\n\x1ak_EGameSearchAction_Cancel\x10\x03*\xbc\x02\n\x11\x45GameSearchResult\x12\x1f\n\x1bk_EGameSearchResult_Invalid\x10\x00\x12(\n$k_EGameSearchResult_SearchInProgress\x10\x01\x12+\n\'k_EGameSearchResult_SearchFailedNoHosts\x10\x02\x12\'\n#k_EGameSearchResult_SearchGameFound\x10\x03\x12.\n*k_EGameSearchResult_SearchCompleteAccepted\x10\x04\x12.\n*k_EGameSearchResult_SearchCompleteDeclined\x10\x05\x12&\n\"k_EGameSearchResult_SearchCanceled\x10\x06\x32{\n\x11QueuedMatchmaking\x12\x66\n\rSearchForGame\x12).CQueuedMatchmaking_SearchForGame_Request\x1a*.CQueuedMatchmaking_SearchForGame_Response2\x8a\x03\n\x19QueuedMatchmakingGameHost\x12\x7f\n\x10SearchForPlayers\x12\x34.CQueuedMatchmakingGameHost_SearchForPlayers_Request\x1a\x35.CQueuedMatchmakingGameHost_SearchForPlayers_Response\x12\x85\x01\n\x12SubmitPlayerResult\x12\x36.CQueuedMatchmakingGameHost_SubmitPlayerResult_Request\x1a\x37.CQueuedMatchmakingGameHost_SubmitPlayerResult_Response\x12\x64\n\x07\x45ndGame\x12+.CQueuedMatchmakingGameHost_EndGame_Request\x1a,.CQueuedMatchmakingGameHost_EndGame_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_qms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EGAMESEARCHACTION._serialized_start=1828
  _EGAMESEARCHACTION._serialized_end=1974
  _EGAMESEARCHRESULT._serialized_start=1977
  _EGAMESEARCHRESULT._serialized_end=2293
  _GAMESEARCHPARAM._serialized_start=87
  _GAMESEARCHPARAM._serialized_end=137
  _CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST._serialized_start=140
  _CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST._serialized_end=373
  _CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE._serialized_start=376
  _CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE._serialized_end=767
  _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST._serialized_start=770
  _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST._serialized_end=1049
  _PLAYERFOUND._serialized_start=1052
  _PLAYERFOUND._serialized_end=1199
  _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE._serialized_start=1202
  _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE._serialized_end=1466
  _PLAYERRESULT._serialized_start=1468
  _PLAYERRESULT._serialized_end=1514
  _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST._serialized_start=1516
  _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST._serialized_end=1642
  _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE._serialized_start=1644
  _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE._serialized_end=1700
  _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST._serialized_start=1702
  _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST._serialized_end=1778
  _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE._serialized_start=1780
  _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE._serialized_end=1825
  _QUEUEDMATCHMAKING._serialized_start=2295
  _QUEUEDMATCHMAKING._serialized_end=2418
  _QUEUEDMATCHMAKINGGAMEHOST._serialized_start=2421
  _QUEUEDMATCHMAKINGGAMEHOST._serialized_end=2815
_builder.BuildServices(DESCRIPTOR, 'steammessages_qms_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_appoverview.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_appoverview.proto\x1a\x0b\x65nums.proto\"\xf9\x02\n\x1a\x43\x41ppOverview_PerClientData\x12\x13\n\x08\x63lientid\x18\x01 \x01(\x04:\x01\x30\x12\x13\n\x0b\x63lient_name\x18\x02 \x01(\t\x12@\n\x0e\x64isplay_status\x18\x03 \x01(\x0e\x32\x0f.EDisplayStatus:\x17k_EDisplayStatusInvalid\x12\x19\n\x11status_percentage\x18\x04 \x01(\r\x12\x13\n\x0b\x61\x63tive_beta\x18\x05 \x01(\t\x12\x11\n\tinstalled\x18\x06 \x01(\x08\x12!\n\x19streaming_to_local_client\x18\t \x01(\x08\x12(\n is_available_on_current_platform\x18\n \x01(\x08\x12\x1a\n\x12is_invalid_os_type\x18\x0b \x01(\x08\x12\x15\n\rplaytime_left\x18\x0c \x01(\r\x12,\n$update_available_but_disabled_by_app\x18\x0e \x01(\x08\"\xc5\x0c\n\x0c\x43\x41ppOverview\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x1c\n\x14visible_in_game_list\x18\x04 \x01(\x08\x12\x15\n\rsubscribed_to\x18\x05 \x01(\x08\x12\x0f\n\x07sort_as\x18\x06 \x01(\t\x12\x33\n\x08\x61pp_type\x18\x07 \x01(\x0e\x32\x0e.EProtoAppType:\x11k_EAppTypeInvalid\x12\x11\n\tmru_index\x18\r \x01(\r\x12\"\n\x17rt_recent_activity_time\x18\x0e \x01(\r:\x01\x30\x12#\n\x18minutes_playtime_forever\x18\x10 \x01(\r:\x01\x30\x12*\n\x1fminutes_playtime_last_two_weeks\x18\x11 \x01(\r:\x01\x30\x12\x1e\n\x13rt_last_time_played\x18\x12 \x01(\r:\x01\x30\x12\x11\n\tstore_tag\x18\x13 \x03(\r\x12\x16\n\x0estore_category\x18\x17 \x03(\r\x12#\n\x18rt_original_release_date\x18\x19 \x01(\r:\x01\x30\x12 \n\x15rt_steam_release_date\x18\x1a \x01(\r:\x01\x30\x12\x11\n\ticon_hash\x18\x1b \x01(\t\x12^\n\x17xbox_controller_support\x18\x1f \x01(\x0e\x32\x1b.EAppControllerSupportLevel: k_EAppControllerSupportLevelNone\x12\x14\n\x0cvr_supported\x18  \x01(\x08\x12\x18\n\x10metacritic_score\x18$ \x01(\r\x12\x14\n\x0csize_on_disk\x18% \x01(\x04\x12\x17\n\x0fthird_party_mod\x18& \x01(\x08\x12\x11\n\ticon_data\x18\' \x01(\t\x12\x18\n\x10icon_data_format\x18( \x01(\t\x12\x0e\n\x06gameid\x18) \x01(\t\x12 \n\x18library_capsule_filename\x18* \x01(\t\x12\x34\n\x0fper_client_data\x18+ \x03(\x0b\x32\x1b.CAppOverview_PerClientData\x12\"\n\x17most_available_clientid\x18, \x01(\x04:\x01\x30\x12\x1c\n\x11selected_clientid\x18- \x01(\x04:\x01\x30\x12\x1c\n\x14rt_store_asset_mtime\x18. \x01(\r\x12\x1d\n\x15rt_custom_image_mtime\x18/ \x01(\r\x12\x1e\n\x16optional_parent_app_id\x18\x30 \x01(\r\x12\x18\n\x10owner_account_id\x18\x31 \x01(\r\x12\"\n\x17review_score_with_bombs\x18\x35 \x01(\r:\x01\x30\x12\'\n\x1creview_percentage_with_bombs\x18\x36 \x01(\r:\x01\x30\x12%\n\x1areview_score_without_bombs\x18\x37 \x01(\r:\x01\x30\x12*\n\x1freview_percentage_without_bombs\x18\x38 \x01(\r:\x01\x30\x12\x12\n\nlibrary_id\x18\x39 \x01(\t\x12\x0f\n\x07vr_only\x18: \x01(\x08\x12\x17\n\x0fmastersub_appid\x18; \x01(\r\x12#\n\x1bmastersub_includedwith_logo\x18< \x01(\t\x12\x1e\n\x16site_license_site_name\x18> \x01(\t\x12\x1f\n\x17shortcut_override_appid\x18? \x01(\r\x12#\n\x1brt_last_time_locally_played\x18\x41 \x01(\r\x12\x19\n\x11rt_purchased_time\x18\x42 \x01(\r\x12\x17\n\x0fheader_filename\x18\x43 \x01(\t\x12\x1b\n\x13local_cache_version\x18\x44 \x01(\r\x12\x1b\n\x10number_of_copies\x18H \x01(\r:\x01\x31\x12*\n\x1fsteam_hw_compat_category_packed\x18I \x01(\r:\x01\x30\x12\x18\n\x10\x61lbum_cover_hash\x18J \x01(\t\x12\"\n\x16\x64isplay_name_elanguage\x18K \x01(\x05:\x02-1\x12\x1a\n\x12has_custom_sort_as\x18L \x01(\x08\"\x7f\n\x13\x43\x41ppOverview_Change\x12#\n\x0c\x61pp_overview\x18\x01 \x03(\x0b\x32\r.CAppOverview\x12\x15\n\rremoved_appid\x18\x02 \x03(\r\x12\x13\n\x0b\x66ull_update\x18\x03 \x01(\x08\x12\x17\n\x0fupdate_complete\x18\x04 \x01(\x08*\xcc\n\n\x0e\x45\x44isplayStatus\x12\x1b\n\x17k_EDisplayStatusInvalid\x10\x00\x12\x1d\n\x19k_EDisplayStatusLaunching\x10\x01\x12 \n\x1ck_EDisplayStatusUninstalling\x10\x02\x12\x1e\n\x1ak_EDisplayStatusInstalling\x10\x03\x12\x1b\n\x17k_EDisplayStatusRunning\x10\x04\x12\x1e\n\x1ak_EDisplayStatusValidating\x10\x05\x12\x1c\n\x18k_EDisplayStatusUpdating\x10\x06\x12\x1f\n\x1bk_EDisplayStatusDownloading\x10\x07\x12!\n\x1dk_EDisplayStatusSynchronizing\x10\x08\x12\"\n\x1ek_EDisplayStatusReadyToInstall\x10\t\x12\"\n\x1ek_EDisplayStatusReadyToPreload\x10\n\x12!\n\x1dk_EDisplayStatusReadyToLaunch\x10\x0b\x12$\n k_EDisplayStatusRegionRestricted\x10\x0c\x12\x1f\n\x1bk_EDisplayStatusPresaleOnly\x10\r\x12#\n\x1fk_EDisplayStatusInvalidPlatform\x10\x0e\x12#\n\x1fk_EDisplayStatusPreloadComplete\x10\x10\x12\"\n\x1ek_EDisplayStatusBorrowerLocked\x10\x11\x12 \n\x1ck_EDisplayStatusUpdatePaused\x10\x12\x12 \n\x1ck_EDisplayStatusUpdateQueued\x10\x13\x12\"\n\x1ek_EDisplayStatusUpdateRequired\x10\x14\x12\"\n\x1ek_EDisplayStatusUpdateDisabled\x10\x15\x12\"\n\x1ek_EDisplayStatusDownloadPaused\x10\x16\x12\"\n\x1ek_EDisplayStatusDownloadQueued\x10\x17\x12$\n k_EDisplayStatusDownloadRequired\x10\x18\x12$\n k_EDisplayStatusDownloadDisabled\x10\x19\x12\"\n\x1ek_EDisplayStatusLicensePending\x10\x1a\x12\"\n\x1ek_EDisplayStatusLicenseExpired\x10\x1b\x12 \n\x1ck_EDisplayStatusAvailForFree\x10\x1c\x12!\n\x1dk_EDisplayStatusAvailToBorrow\x10\x1d\x12\"\n\x1ek_EDisplayStatusAvailGuestPass\x10\x1e\x12\x1c\n\x18k_EDisplayStatusPurchase\x10\x1f\x12\x1f\n\x1bk_EDisplayStatusUnavailable\x10 \x12!\n\x1dk_EDisplayStatusNotLaunchable\x10!\x12\x1e\n\x1ak_EDisplayStatusCloudError\x10\"\x12\"\n\x1ek_EDisplayStatusCloudOutOfDate\x10#\x12\x1f\n\x1bk_EDisplayStatusTerminating\x10$\x12\x1f\n\x1bk_EDisplayStatusOwnerLocked\x10%\x12\"\n\x1ek_EDisplayStatusDownloadFailed\x10&\x12 \n\x1ck_EDisplayStatusUpdateFailed\x10\'*\xf7\x02\n\x0f\x45\x41ppCloudStatus\x12\x1c\n\x18k_EAppCloudStatusInvalid\x10\x00\x12\x1d\n\x19k_EAppCloudStatusDisabled\x10\x01\x12\x1c\n\x18k_EAppCloudStatusUnknown\x10\x02\x12!\n\x1dk_EAppCloudStatusSynchronized\x10\x03\x12\x1d\n\x19k_EAppCloudStatusChecking\x10\x04\x12\x1e\n\x1ak_EAppCloudStatusOutOfSync\x10\x05\x12\x1e\n\x1ak_EAppCloudStatusUploading\x10\x06\x12 \n\x1ck_EAppCloudStatusDownloading\x10\x07\x12\x1f\n\x1bk_EAppCloudStatusSyncFailed\x10\x08\x12\x1d\n\x19k_EAppCloudStatusConflict\x10\t\x12%\n!k_EAppCloudStatusPendingElsewhere\x10\n*\x91\x01\n\x1a\x45\x41ppControllerSupportLevel\x12$\n k_EAppControllerSupportLevelNone\x10\x00\x12\'\n#k_EAppControllerSupportLevelPartial\x10\x01\x12$\n k_EAppControllerSupportLevelFull\x10\x02*\xfd\x01\n#EAppGamepadGyroTrackpadSupportLevel\x12\x39\n,k_EAppGamepadGyroTrackpadSupportLevelUnknown\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n.k_EAppGamepadGyroTrackpadSupportLevelNoGamepad\x10\x00\x12\x30\n,k_EAppGamepadGyroTrackpadSupportLevelGamepad\x10\x01\x12\x35\n1k_EAppGamepadGyroTrackpadSupportLevelSimultaneous\x10\x02*\xa1\x01\n\x0e\x45\x41ppHDRSupport\x12\x19\n\x15k_EHDRSupport_Unknown\x10\x00\x12\x15\n\x11k_EHDRSupport_SDR\x10\x01\x12\x15\n\x11k_EHDRSupport_HDR\x10\x02\x12\x1c\n\x18k_EHDRSupport_HDR_Broken\x10\x03\x12(\n$k_EHDRSupport_HDR_RequiresUserAction\x10\x04\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_appoverview_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _EDISPLAYSTATUS._serialized_start=2166
  _EDISPLAYSTATUS._serialized_end=3522
  _EAPPCLOUDSTATUS._serialized_start=3525
  _EAPPCLOUDSTATUS._serialized_end=3900
  _EAPPCONTROLLERSUPPORTLEVEL._serialized_start=3903
  _EAPPCONTROLLERSUPPORTLEVEL._serialized_end=4048
  _EAPPGAMEPADGYROTRACKPADSUPPORTLEVEL._serialized_start=4051
  _EAPPGAMEPADGYROTRACKPADSUPPORTLEVEL._serialized_end=4304
  _EAPPHDRSUPPORT._serialized_start=4307
  _EAPPHDRSUPPORT._serialized_end=4468
  _CAPPOVERVIEW_PERCLIENTDATA._serialized_start=49
  _CAPPOVERVIEW_PERCLIENTDATA._serialized_end=426
  _CAPPOVERVIEW._serialized_start=429
  _CAPPOVERVIEW._serialized_end=2034
  _CAPPOVERVIEW_CHANGE._serialized_start=2036
  _CAPPOVERVIEW_CHANGE._serialized_end=2163
# @@protoc_insertion_point(module_scope)
